# Embeddings

Input feature maps for coordinate-based learning.

!!! note
    Key notes:

    - Random Fourier features approximate stationary kernels via $\phi(x)=[\cos(Bx),\sin(Bx)]$.

::: phydrax.nn.RandomFourierFeatureEmbeddings
    options:
        members:
            - __init__
            - __call__
